@@ -75,7 +75,19 @@ class LogWatcher:
         self.end_flag = True
         if self.t:
             self.t.join()
+        
+        if not self.statistic_printed:
+            self._parse_whole_log()
+    
+    def _parse_whole_log(self):
+        logger.warning(
+            "LogWatcher closed without reading the statistics, parsing the whole log now."
+        )
+        with open(self.log_file, "r", encoding="utf-8") as fp:
+            content = fp.read()
+            self.parse_log(content)
 
 
 if __name__ == "__main__":
-    LogWatcher("/Users/atria/Desktop/coding/Kea2/output/res_2025062510_0420056539/fastbot_2025062510_0420056539.log")
\ No newline at end of file
+    # LogWatcher()
+    pass
\ No newline at end of file
